@@ -8,6 +8,7 @@ from collections import defaultdict
 import glob
 import logging
 import io
+import requests
 import urllib.parse
 import traceback
 import base64
@@ -20,7 +21,7 @@ import dqueue.tools as tools
 import peewee # type: ignore
 import json
 
-from flask import render_template,make_response,request,jsonify,Flask,Response
+from flask import render_template, make_response, request, jsonify, Flask, Response, url_for
 from flasgger import Swagger, SwaggerView, Schema, fields # type: ignore
 
 import odakb
@@ -61,6 +62,9 @@ class Task(Schema):
     task_key = fields.Str()
     task_data = TaskData
 
+class CallbackPayload(Schema):
+    url = fields.Str()
+
 class TaskList(Schema):
     tasks = fields.Nested(Task, many=True)
 
@@ -235,7 +239,7 @@ class WorkerAnswer(SwaggerView):
 
         queue.task_done()
 
-        # here also upload data nad store 
+        # here also upload data nad store?
 
         return jsonify(
                     { 'task_key': task.key, **task.as_dict}
@@ -739,6 +743,123 @@ app.add_url_rule(
           methods=['GET']
 )
 
+class TaskMoveView(SwaggerView):
+    operationId = "move_task"
+
+    parameters = [
+                {
+                    'name': 'task_key',
+                    'in': 'path',
+                    'required': True,
+                    'type': 'string',
+                },
+                {
+                    'name': 'fromk',
+                    'in': 'path',
+                    'required': True,
+                    'type': 'string',
+                },
+                {
+                    'name': 'tok',
+                    'in': 'path',
+                    'required': True,
+                    'type': 'string',
+                },
+                {
+                    'name': 'update_entry',
+                    'in': 'body',
+                    'required': True,
+                    'schema': Task,
+                },
+            ]
+
+    responses = {
+            200: {
+                    'description': 'task data',
+                }
+        }
+
+    def get(self, task_key, fromk, tok):
+        queue = dqueue.core.Queue()
+
+        update_entry = request.json
+
+        if len(update_entry) == 0:
+            update_entry = None
+
+        logger.info("requested to move from %s to %s task_key %s", fromk, tok, task_key)
+
+        queue.log_task(message=f"moving task from {fromk} to {tok}, update_entry {len(update_entry or [])}", task_key=task_key, state=tok)
+        
+        logger.warning("queue before move %s", queue.list_tasks(states=["done", "waiting"]))
+
+        queue.move_task(fromk=fromk,
+                        tok=tok,
+                        task=task_key,
+                        update_entry=json.dumps(update_entry)
+                        )
+        
+        logger.warning("queue after move %s", queue.list_tasks(states=["done", "waiting"]))
+
+        return jsonify(
+                {}
+            )
+
+app.add_url_rule(
+         '/tasks/move/<task_key>/<fromk>/<tok>',
+          view_func=TaskMoveView.as_view('move_task'),
+          methods=['GET']
+)
+
+class TaskCallbackView(SwaggerView):
+    operationId = "callback"
+
+    parameters = [
+                {
+                    'name': 'payload',
+                    'in': 'body',
+                    'required': True,
+                    'schema': CallbackPayload,
+                },
+            ]
+
+    responses = {
+            200: {
+                    'description': 'success',
+                }
+        }
+
+    def post(self):
+        payload = request.json
+
+        url = payload['url']
+        params = payload['params']
+
+        logger.info("callback %s, params %s", url, params)
+
+        allowed_dispatcher = [
+                    "http://oda-dispatcher:8000",
+                    url_for('healthcheck', _external=True),
+                ]
+
+        if any([url.startswith(p) for p in allowed_dispatcher]):
+            r = requests.get(url, params=params)
+        else:
+            raise RuntimeError(f"unable to deal with non-standard dispatcher, allowed {allowed_dispatcher}")
+
+        return jsonify(
+                dict(
+                    status = r.status_code,
+                    text = r.text ,
+                )
+            )
+
+app.add_url_rule(
+         '/worker/callback',
+          view_func=TaskCallbackView.as_view('callback'),
+          methods=['POST']
+)
+
 @app.route("/tasks/resubmit/<string:scope>/<string:selector>")
 def tasks_resubmit(scope, selector):
     """
