@@ -513,27 +513,38 @@ class Queue:
         logger.warning('this is very desctructive: clearing event log')
         EventLog.delete().execute(database=None)
 
-    def move_task(self, fromk, tok, task, update_entry=False, n_tries_left=1):
+    #def move_task(self, fromk: str, tok: str, task, update_entry=False, n_tries_left=1):
+    def move_task(self, fromk: str, tok: str, task, update_entry=None, n_tries_left=1):
         "moves task"
 
+        logger.info("%s moving task %s from %s to %s", self, task, fromk, tok)
+
+        if isinstance(task, Task):
+            task_key = task.key
+        else:
+            task_key = task
+
+
         retry_delay=2
 
         if n_tries_left<=0:
             return
             
         extra = {}
+
+        #if update_entry:
+        #    extra = {TaskEntry.task_dict_string: self.current_task.serialize()}
         if update_entry:
-            extra = {TaskEntry.task_dict_string: self.current_task.serialize()}
+            extra = {TaskEntry.task_dict_string: update_entry}
 
         try:
-
-            r=TaskEntry.update({
+            r = TaskEntry.update({
                             TaskEntry.state:tok,
                             TaskEntry.worker_id:self.worker_id,
                             TaskEntry.modified:datetime.datetime.now(),
                             **extra
                         })\
-                        .where(TaskEntry.state==fromk, TaskEntry.key==task.key).execute(database=None)
+                        .where(TaskEntry.state==fromk, TaskEntry.key==task_key).execute(database=None)
 
         except Exception as e:
             logger.error('failed to move task: %s', repr(e))
@@ -677,10 +688,12 @@ class Queue:
 
     def task_locked(self, depends_on: List[dqtyping.TaskDict]):
         ""
+
+
         if not isinstance(depends_on, list):
             raise Exception(f"depends_on has unknown type {depends_on.__class__}, expected list")
 
-        log("locking task",self.current_task)
+        logger.info("%s locking task %s", self, self.current_task)
         self.log_task(f"task to lock by {len(depends_on)} dependencies", state="locking")
         if self.current_task is None:
             raise Exception("task must be available to lock")
@@ -717,7 +730,11 @@ class Queue:
 
         self.log_task("task to lock: serialized to %i"%len(serialized), state="locked")
 
-        self.move_task('running', 'locked', self.current_task, update_entry=True, n_tries_left=30)
+        self.move_task('running', 'locked', 
+                       self.current_task, 
+                       update_entry=self.current_task.serialize(),
+                       #update_entry=True, 
+                       n_tries_left=30)
         
         self.log_task("task locked from "+str(self.current_task_status),state="locked")
 
