@@ -1,6 +1,7 @@
 import datetime
 import os
 import time
+import json
 import socket
 from hashlib import sha224
 from collections import defaultdict
@@ -75,7 +76,10 @@ class QueueProxy(DataFacts, Queue):
             if task is None:
                 task = self.current_task
 
-            task_key = task.key
+            if task is None:
+                task_key = "None"
+            else:
+                task_key = task.key
 
         def _log_task():
             return self.client.worker.logTask(message=message, 
@@ -147,6 +151,29 @@ class QueueProxy(DataFacts, Queue):
 
         return r
 
+    def move_task(self, fromk, tok, task, update_entry=None, n_tries_left=0):
+        if isinstance(task, str):
+            task_key = task
+        else:
+            task_key = task.key
+
+        self.logger.info("moving task %s from %s to %s", task_key, fromk, tok)
+
+        self.logger.info(dir(self.client.tasks))
+
+        r = self.client.tasks.move_task(
+                                      #worker_id=self.worker_id, 
+                                      #queue=self.queue, 
+                                      task_key=task_key,
+                                      fromk=fromk,
+                                      tok=tok,
+                                      update_entry=json.loads(update_entry or '{}'), # todo
+                                      ).response().result
+
+        self.current_task = None
+
+        return r
+
     def clear_task_history(self):
         raise NotImplementedError
 
@@ -188,4 +215,14 @@ class QueueProxy(DataFacts, Queue):
     def try_all_locked(self):
         return self.client.tasks.try_all_locked(worker_id=self.worker_id, queue=self.queue).response().result
 
+    def callback(self, url, params):
+        """
+        """
+        return self.client.worker.callback(
+                    payload=dict(
+                            url = url,
+                            params = params,
+                        )
+                ).response().result
+
 
